@@ -4,9 +4,12 @@ import logging
 from datetime import datetime, timezone
 from errno import ENOTEMPTY
 from io import BytesIO
+from pathlib import PurePath, PureWindowsPath
 from typing import Any, ClassVar
 
 from fsspec import AbstractFileSystem
+from fsspec.implementations.local import LocalFileSystem
+from fsspec.utils import stringify_path
 
 logger = logging.getLogger("fsspec.memoryfs")
 
@@ -25,6 +28,12 @@ class MemoryFileSystem(AbstractFileSystem):
 
     @classmethod
     def _strip_protocol(cls, path):
+        if isinstance(path, PurePath):
+            if isinstance(path, PureWindowsPath):
+                return LocalFileSystem._strip_protocol(path)
+            else:
+                path = stringify_path(path)
+
         if path.startswith("memory://"):
             path = path[len("memory://") :]
         if "::" in path or "://" in path:
